unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Db, DBTables, ExtCtrls, ShellApi,
  mtrServer, mtrCustomServers, mtrClient, mtrHtmlView, mtrDesigner,
  mtrView, mtrRtfView;

type
  TfmMain = class(TForm)
    btConnect: TButton;
    btDisconnect: TButton;
    btStart: TButton;
    Database: TDatabase;
    btSchema: TButton;
    rgRpt: TRadioGroup;
    btTemplate: TButton;
    gbView: TGroupBox;
    rbHTML: TRadioButton;
    rbRTF: TRadioButton;
    mtrBDEServer: TmtrBDEServer;
    mtrClient: TmtrClient;
    mtrDesigner: TmtrDesigner;
    mtrHtmlView: TmtrHtmlView;
    mtrRtfView: TmtrRtfView;
    procedure btConnectClick(Sender: TObject);
    procedure btDisconnectClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure btStartClick(Sender: TObject);
    procedure btSchemaClick(Sender: TObject);
    procedure btTemplateClick(Sender: TObject);
    procedure rbHTMLClick(Sender: TObject);
    procedure rbRTFClick(Sender: TObject);
  private
    { Private declarations }
    FPath: string;
  public
    { Public declarations }
  end;

var
  fmMain: TfmMain;

implementation

const
  SchemaArr: array [0..5] of string = (
    'list1',
    'masterdetail1',
    'masterdetail2',
    'crosstab1',
    'chart1',
    'chart2'
    );

{$R *.DFM}

procedure TfmMain.btConnectClick(Sender: TObject);
begin
  Database.Open;
  btConnect.Enabled := false;
  btDisconnect.Enabled := true;
  btStart.Enabled := true;
  btSchema.Enabled := true;
  btTemplate.Enabled := true;
end;

procedure TfmMain.btDisconnectClick(Sender: TObject);
begin
  Database.Close;
  btConnect.Enabled := true;
  btDisconnect.Enabled := false;
  btStart.Enabled := false;
  btSchema.Enabled := false;
  btTemplate.Enabled := false;
end;

procedure TfmMain.FormCreate(Sender: TObject);
var
  p: integer;
begin
  //locate demo shared directory
  FPath := AnsiUpperCase(Application.ExeName);
  p := Pos('\2TIER', FPath);
  FPath := Copy(FPath, 1, p) + '\SHARED\';
  mtrHtmlView.TemplateDir := FPath;
  mtrRtfView.TemplateDir := FPath;
end;

procedure TfmMain.btStartClick(Sender: TObject);
begin
  mtrClient.LoadFromFile(FPath + SchemaArr[rgRpt.ItemIndex] + '.config');

  mtrClient.Params.Clear;
  //for "Master/detail with parameters" add one parameter
  if rgRpt.ItemIndex = 2 then
    mtrClient.Params.Add('company', 'K%');

  mtrClient.Execute;
end;

procedure TfmMain.btSchemaClick(Sender: TObject);
begin
  mtrDesigner.FileName := FPath + SchemaArr[rgRpt.ItemIndex] + '.config';
  mtrDesigner.ShowDesigner;
end;

procedure TfmMain.btTemplateClick(Sender: TObject);
var
  s: string;
begin
  s := FPath + SchemaArr[rgRpt.ItemIndex];
  if rbHTML.Checked then begin
    ShellExecute(HWND(nil), 'Edit', PChar(s + '.htm'), nil, nil, SW_SHOWNORMAL);
  end
  else if rbRTF.Checked then begin
    ShellExecute(HWND(nil), 'Open', PChar(s + '.rtf'), nil, nil, SW_SHOWNORMAL);
  end;
end;

procedure TfmMain.rbHTMLClick(Sender: TObject);
begin
  mtrClient.Viewer := mtrHtmlView;
end;

procedure TfmMain.rbRTFClick(Sender: TObject);
begin
  mtrClient.Viewer := mtrRtfView;
end;

end.
